[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,95 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief Jacobi method with parallel_for
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
#include <iostream>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main(int argc, char** argv)
|
||||
{
|
||||
context ctx;
|
||||
|
||||
size_t n = 4096;
|
||||
size_t m = 4096;
|
||||
double tol = 0.5;
|
||||
size_t iter_max = 1000;
|
||||
|
||||
if (argc > 2)
|
||||
{
|
||||
n = atol(argv[1]);
|
||||
m = atol(argv[2]);
|
||||
}
|
||||
|
||||
if (argc > 3)
|
||||
{
|
||||
tol = atof(argv[3]);
|
||||
}
|
||||
|
||||
if (argc > 4)
|
||||
{
|
||||
iter_max = atoi(argv[4]);
|
||||
}
|
||||
|
||||
auto lA = ctx.logical_data(shape_of<slice<double, 2>>(m, n));
|
||||
auto lAnew = ctx.logical_data(lA.shape());
|
||||
|
||||
ctx.parallel_for(lA.shape(), lA.write(), lAnew.write()).set_symbol("init")->*
|
||||
[=] __device__(size_t i, size_t j, auto A, auto Anew) {
|
||||
A(i, j) = (i == j) ? 10.0 : -1.0;
|
||||
Anew(i, j) = A(i, j);
|
||||
};
|
||||
|
||||
cudaEvent_t start, stop;
|
||||
|
||||
cuda_safe_call(cudaEventCreate(&start));
|
||||
cuda_safe_call(cudaEventCreate(&stop));
|
||||
|
||||
cuda_safe_call(cudaEventRecord(start, ctx.fence()));
|
||||
|
||||
auto lresidual = ctx.logical_data(shape_of<scalar_view<double>>());
|
||||
|
||||
size_t iter = 0;
|
||||
do
|
||||
{
|
||||
ctx.parallel_for(inner<1>(lA.shape()), lA.read(), lAnew.rw(), lresidual.reduce(reducer::maxval<double>{}))
|
||||
->*[] __device__(size_t i, size_t j, auto A, auto Anew, auto& residual) {
|
||||
Anew(i, j) = 0.25 * (A(i - 1, j) + A(i + 1, j) + A(i, j - 1) + A(i, j + 1));
|
||||
residual = ::std::max(residual, fabs(A(i, j) - Anew(i, j)));
|
||||
};
|
||||
|
||||
ctx.parallel_for(inner<1>(lA.shape()), lA.rw(), lAnew.read())->*[] __device__(size_t i, size_t j, auto A, auto Anew) {
|
||||
A(i, j) = Anew(i, j);
|
||||
};
|
||||
|
||||
iter++;
|
||||
|
||||
} while (ctx.wait(lresidual) > tol && iter < iter_max);
|
||||
|
||||
cuda_safe_call(cudaEventRecord(stop, ctx.fence()));
|
||||
|
||||
double final_residual = ctx.wait(lresidual);
|
||||
|
||||
printf("Converged after %ld iterations, residual = %lf\n", iter, final_residual);
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
float elapsedTime;
|
||||
cudaEventElapsedTime(&elapsedTime, start, stop);
|
||||
printf("Elapsed time: %f ms\n", elapsedTime);
|
||||
}
|
||||
Reference in New Issue
Block a user